
=================
Quantum Cognition
=================

Blogs
=====

* `量子认知解谜 <http://m.v4.cc/News-507509.html>`_. 此前被认为非理性的一些认知
  和决策方式，被发现可以用量子力学模型来描述和预测；量子认知有望成为超越理性与非理性
  之争的新途径。
* 机器之心, `玄妙至极的量子认知，能否解释人类的不理性行为？
  <https://www.jiqizhixin.com/articles/32fb817a-74d5-4c31-819b-a3ad8150fe63>`_.
  量子意识，是一个将量子物理学的原理应用到心理学上的新兴理论。量子力学理论通过对原子以及
  组成原子的微小粒子的行为作出精确预测而获得了认可。没人真的理解量子力学意味着什么，但是
  它的确有效。这就是它的吸引力，因此其它领域的学者们可能想要借取量子力学的见解也是可理解
  的了。
* `量子世界的认知：你看见的，绝对不是世界的全部 <http://www.sohu.com/a/54282463_358836>`_.
  波粒二象性是量子力学的本质吗？不确定原理的后面就是不可知论吗？薛定谔猫是最诡异的吗？
  爱因斯坦真正被量子纠缠打败了吗？量子思维.分布式人工智能.区块链.
* `继续量子科学革命 <http://epaper.gmw.cn/gmrb/html/2017-05/25/nw.D110000gmrb_20170525_1-13.htm>`_.
  量子力学没有动摇科学的一个基本方针，即客观世界和客观规律不依赖于人的意志。这也将引导量子力学的进一步完善。
* `施一公：生命科学认知的极限 <http://www.toutiao.com/i6241001785603916290/>`_.我认为
  人类的认知极限就在于，我们是一堆原子，我们处在宏观世界，但我们希望隔着两个世界去看超微观
  世界。那是一个最美好的、极其美妙的世界。
* `用量子概率预测人类行为 <http://www.guokr.com/article/438823/#%E6%96%87%E7%8C%AE2>`_.
  量子理论的基本概念和原理，比如叠加（superposition）、干涉（interference）和相容（compatibility），
  其实跟传统心理学和认知科学的直觉很一致，从而为改善认知理论和数学模型提供了新颖、优雅而又完整的数学
  理论框架。量子认知科学的诞生，解决了传统理论无法系统解释人类决策行为中非理性现象的难题，打破了社会
  科学把人类行为和思维束缚在经典概率理论框架内的窘境。


